from setuptools import setup, find_packages

setup(
    name='ali-express-scraper',
    version='0.1.1',
    packages=find_packages(),
    author='Oxylabs',
    author_email='marketing@oxylabs.io',
    description="Easily collect public AliExpress data like prices, product details, and ratings with AliExpress Scraper API",
    long_description="""# AliExpress Scraper

[![Oxylabs promo code](https://user-images.githubusercontent.com/129506779/250792357-8289e25e-9c36-4dc0-a5e2-2706db797bb5.png)](https://oxylabs.go2cloud.org/aff_c?offer_id=7&aff_id=877&url_id=112)

[<u>AliExpress Scraper</u>](https://oxylabs.io/products/scraper-api/ecommerce/aliexpress) is a tool designed to collect public product data
from AliExpress on a large scale. This short tutorial will show you how
to scrape AliExpress with Oxylabs’ Scraper API.

## How it works

You can extract AliExpress data by sending a request to our API with
URLs you want to scrape. Our service will send back the HTML of any
AliExpress page.

### Python code example

This sample showcases how to make an API request and retrieve the HTML
of AliExpress search results for the keyword “laptop”:

```python
import requests
from pprint import pprint

# Structure payload.
payload = {
    'source': 'universal_ecommerce',
    'url': 'https://www.aliexpress.com/w/wholesale-laptop.html?catId=0&initiative_id=SB_20230907055110&SearchText=laptop&spm=a2g0o.best.1000002.0',
    'user_agent_type': 'desktop',
    'render': 'html',
    'geo_location': 'Germany'
}

# Get response.
response = requests.request(
    'POST',
    'https://realtime.oxylabs.io/v1/queries',
    auth=('USERNAME', 'PASSWORD'), #Your credentials go here
    json=payload,
)

# Instead of response with job status and results url, this will return the
# JSON response with results.
pprint(response.json())

```

See the
[<u>documentation</u>](https://developers.oxylabs.io/scraper-apis/e-commerce-scraper-api/aliexpress)
for more code samples.

### Output sample

```json
{
  "results": [
    {
      "content": "<!doctype html>\n<html lang=\"en\">\n<head>
      ...
      </script></body>\n</html>\n",
      "created_at": "2023-09-07 14:04:18",
      "updated_at": "2023-09-07 14:04:42",
      "page": 1,
      "url": "https://www.aliexpress.com/w/wholesale-laptop.html?catId=0&initiative_id=SB_20230907055110&SearchText=laptop&spm=a2g0o.best.1000002.0",
      "job_id": "7105551359235115009",
      "status_code": 200
    }
  ]
}
```

The data harvesting process is significantly easier with Oxylabs’
AliExpress Scraper API. You can collect details such as pricing,
reviews, product information, and other public data. If you have any
questions, you can contact us via [<u>live
chat</u>](https://oxylabs.io/) or
[<u>email</u>](mailto:support@oxylabs.io).

""",
    long_description_content_type='text/markdown',
    url='https://oxylabs.io/products/scraper-api/ecommerce/aliexpress',
    project_urls={
        'Documentation': 'https://developers.oxylabs.io/scraper-apis/e-commerce-scraper-api/aliexpress?_gl=1*1otqxkq*_gcl_aw*R0NMLjE3MDg1MTU0ODYuQ2p3S0NBaUEyOWF1QmhCeEVpd0FuS2NTcWtRSWlmdl9Ud19pcWxkM3hSTVNNa1E4SHlCM3p0TDFzdnA5aTE1N0lYckNGQWVtRUdiY29ob0NhUVlRQXZEX0J3RQ..*_gcl_au*MTc2MDgxNTAwNC4xNzA1OTI3MzM0',
        'Source': 'https://github.com/oxylabs/aliexpress-scraper',
        'Bug Reports': 'https://github.com/oxylabs/aliexpress-scraper/issues',
    },
    keywords='aliexpress-api,	aliexpress-scraper,	aliexpress-spider,	scrape-aliexpress',
    license='MIT',

    include_package_data=True,
    zip_safe=False,
    python_requires='>=3.6',
)









